==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/IstioEgressListenerFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class IstioEgressListenerFluentImpl<A extends IstioEgressListenerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IstioEgressListenerFluent<A>{

    private String bind;
    private CaptureMode captureMode;
    private List<String> hosts;
    private PortBuilder port;

    public IstioEgressListenerFluentImpl(){
    }
    public IstioEgressListenerFluentImpl(IstioEgressListener instance){
            this.withBind(instance.getBind()); 
            this.withCaptureMode(instance.getCaptureMode()); 
            this.withHosts(instance.getHosts()); 
            this.withPort(instance.getPort()); 
    }

    public String getBind(){
            return this.bind;
    }

    public A withBind(String bind){
            this.bind=bind; return (A) this;
    }

    public Boolean hasBind(){
            return this.bind != null;
    }

    public A withNewBind(String arg1){
            return (A)withBind(new String(arg1));
    }

    public A withNewBind(StringBuilder arg1){
            return (A)withBind(new String(arg1));
    }

    public A withNewBind(StringBuffer arg1){
            return (A)withBind(new String(arg1));
    }

    public CaptureMode getCaptureMode(){
            return this.captureMode;
    }

    public A withCaptureMode(CaptureMode captureMode){
            this.captureMode=captureMode; return (A) this;
    }

    public Boolean hasCaptureMode(){
            return this.captureMode != null;
    }

    public A addToHosts(int index,String item){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            this.hosts.add(index, item);
            return (A)this;
    }

    public A setToHosts(int index,String item){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            this.hosts.set(index, item); return (A)this;
    }

    public A addToHosts(String... items){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            for (String item : items) {this.hosts.add(item);} return (A)this;
    }

    public A addAllToHosts(Collection<String> items){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            for (String item : items) {this.hosts.add(item);} return (A)this;
    }

    public A removeFromHosts(String... items){
            for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
    }

    public A removeAllFromHosts(Collection<String> items){
            for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
    }

    public List<String> getHosts(){
            return this.hosts;
    }

    public String getHost(int index){
            return this.hosts.get(index);
    }

    public String getFirstHost(){
            return this.hosts.get(0);
    }

    public String getLastHost(){
            return this.hosts.get(hosts.size() - 1);
    }

    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: hosts) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: hosts) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withHosts(List<String> hosts){
            if (this.hosts != null) { _visitables.get("hosts").removeAll(this.hosts);}
            if (hosts != null) {this.hosts = new ArrayList<String>(); for (String item : hosts){this.addToHosts(item);}} else { this.hosts = null;} return (A) this;
    }

    public A withHosts(String... hosts){
            if (this.hosts != null) {this.hosts.clear();}
            if (hosts != null) {for (String item :hosts){ this.addToHosts(item);}} return (A) this;
    }

    public Boolean hasHosts(){
            return hosts != null && !hosts.isEmpty();
    }

    public A addNewHost(String arg1){
            return (A)addToHosts(new String(arg1));
    }

    public A addNewHost(StringBuilder arg1){
            return (A)addToHosts(new String(arg1));
    }

    public A addNewHost(StringBuffer arg1){
            return (A)addToHosts(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Port getPort(){
            return this.port!=null?this.port.build():null;
    }

    public me.snowdrop.istio.api.networking.v1alpha3.Port buildPort(){
            return this.port!=null?this.port.build():null;
    }

    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.Port port){
            _visitables.get("port").remove(this.port);
            if (port!=null){ this.port= new PortBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
    }

    public Boolean hasPort(){
            return this.port != null;
    }

    public A withNewPort(String name,Integer number,String protocol){
            return (A)withPort(new Port(name, number, protocol));
    }

    public IstioEgressListenerFluent.PortNested<A> withNewPort(){
            return new PortNestedImpl();
    }

    public IstioEgressListenerFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item){
            return new PortNestedImpl(item);
    }

    public IstioEgressListenerFluent.PortNested<A> editPort(){
            return withNewPortLike(getPort());
    }

    public IstioEgressListenerFluent.PortNested<A> editOrNewPort(){
            return withNewPortLike(getPort() != null ? getPort(): new PortBuilder().build());
    }

    public IstioEgressListenerFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item){
            return withNewPortLike(getPort() != null ? getPort(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            IstioEgressListenerFluentImpl that = (IstioEgressListenerFluentImpl) o;
            if (bind != null ? !bind.equals(that.bind) :that.bind != null) return false;
            if (captureMode != null ? !captureMode.equals(that.captureMode) :that.captureMode != null) return false;
            if (hosts != null ? !hosts.equals(that.hosts) :that.hosts != null) return false;
            if (port != null ? !port.equals(that.port) :that.port != null) return false;
            return true;
    }


    public class PortNestedImpl<N> extends PortFluentImpl<IstioEgressListenerFluent.PortNested<N>> implements IstioEgressListenerFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PortBuilder builder;
    
            PortNestedImpl(me.snowdrop.istio.api.networking.v1alpha3.Port item){
                    this.builder = new PortBuilder(this, item);
            }
            PortNestedImpl(){
                    this.builder = new PortBuilder(this);
            }
    
    public N and(){
            return (N) IstioEgressListenerFluentImpl.this.withPort(builder.build());
    }
    public N endPort(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/IstioEgressListenerFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class IstioEgressListenerFluentImpl<A extends IstioEgressListenerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IstioEgressListenerFluent<A>{

    private String bind;
    private CaptureMode captureMode;
    private List<String> hosts;
    private PortBuilder port;

    public IstioEgressListenerFluentImpl(){
    }
    public IstioEgressListenerFluentImpl(IstioEgressListener instance){
            this.withBind(instance.getBind()); 
            this.withCaptureMode(instance.getCaptureMode()); 
            this.withHosts(instance.getHosts()); 
            this.withPort(instance.getPort()); 
    }

    public String getBind(){
            return this.bind;
    }

    public A withBind(String bind){
            this.bind=bind; return (A) this;
    }

    public Boolean hasBind(){
            return this.bind != null;
    }

    public A withNewBind(String arg1){
            return (A)withBind(new String(arg1));
    }

    public A withNewBind(StringBuilder arg1){
            return (A)withBind(new String(arg1));
    }

    public A withNewBind(StringBuffer arg1){
            return (A)withBind(new String(arg1));
    }

    public CaptureMode getCaptureMode(){
            return this.captureMode;
    }

    public A withCaptureMode(CaptureMode captureMode){
            this.captureMode=captureMode; return (A) this;
    }

    public Boolean hasCaptureMode(){
            return this.captureMode != null;
    }

    public A addToHosts(int index,String item){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            this.hosts.add(index, item);
            return (A)this;
    }

    public A setToHosts(int index,String item){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            this.hosts.set(index, item); return (A)this;
    }

    public A addToHosts(String... items){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            for (String item : items) {this.hosts.add(item);} return (A)this;
    }

    public A addAllToHosts(Collection<String> items){
            if (this.hosts == null) {this.hosts = new ArrayList<String>();}
            for (String item : items) {this.hosts.add(item);} return (A)this;
    }

    public A removeFromHosts(String... items){
            for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
    }

    public A removeAllFromHosts(Collection<String> items){
            for (String item : items) {if (this.hosts!= null){ this.hosts.remove(item);}} return (A)this;
    }

    public List<String> getHosts(){
            return this.hosts;
    }

    public String getHost(int index){
            return this.hosts.get(index);
    }

    public String getFirstHost(){
            return this.hosts.get(0);
    }

    public String getLastHost(){
            return this.hosts.get(hosts.size() - 1);
    }

    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: hosts) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: hosts) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withHosts(List<String> hosts){
            if (this.hosts != null) { _visitables.get("hosts").removeAll(this.hosts);}
            if (hosts != null) {this.hosts = new ArrayList<String>(); for (String item : hosts){this.addToHosts(item);}} else { this.hosts = null;} return (A) this;
    }

    public A withHosts(String... hosts){
            if (this.hosts != null) {this.hosts.clear();}
            if (hosts != null) {for (String item :hosts){ this.addToHosts(item);}} return (A) this;
    }

    public Boolean hasHosts(){
            return hosts != null && !hosts.isEmpty();
    }

    public A addNewHost(String arg1){
            return (A)addToHosts(new String(arg1));
    }

    public A addNewHost(StringBuilder arg1){
            return (A)addToHosts(new String(arg1));
    }

    public A addNewHost(StringBuffer arg1){
            return (A)addToHosts(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public Port getPort(){
            return this.port!=null?this.port.build():null;
    }

    public Port buildPort(){
            return this.port!=null?this.port.build():null;
    }

    public A withPort(Port port){
            _visitables.get("port").remove(this.port);
            if (port!=null){ this.port= new PortBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
    }

    public Boolean hasPort(){
            return this.port != null;
    }

    public A withNewPort(String name,Integer number,String protocol,Integer targetPort){
            return (A)withPort(new Port(name, number, protocol, targetPort));
    }

    public IstioEgressListenerFluent.PortNested<A> withNewPort(){
            return new PortNestedImpl();
    }

    public IstioEgressListenerFluent.PortNested<A> withNewPortLike(Port item){
            return new PortNestedImpl(item);
    }

    public IstioEgressListenerFluent.PortNested<A> editPort(){
            return withNewPortLike(getPort());
    }

    public IstioEgressListenerFluent.PortNested<A> editOrNewPort(){
            return withNewPortLike(getPort() != null ? getPort(): new PortBuilder().build());
    }

    public IstioEgressListenerFluent.PortNested<A> editOrNewPortLike(Port item){
            return withNewPortLike(getPort() != null ? getPort(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            IstioEgressListenerFluentImpl that = (IstioEgressListenerFluentImpl) o;
            if (bind != null ? !bind.equals(that.bind) :that.bind != null) return false;
            if (captureMode != null ? !captureMode.equals(that.captureMode) :that.captureMode != null) return false;
            if (hosts != null ? !hosts.equals(that.hosts) :that.hosts != null) return false;
            if (port != null ? !port.equals(that.port) :that.port != null) return false;
            return true;
    }


    public class PortNestedImpl<N> extends PortFluentImpl<IstioEgressListenerFluent.PortNested<N>> implements IstioEgressListenerFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PortBuilder builder;
    
            PortNestedImpl(Port item){
                    this.builder = new PortBuilder(this, item);
            }
            PortNestedImpl(){
                    this.builder = new PortBuilder(this);
            }
    
    public N and(){
            return (N) IstioEgressListenerFluentImpl.this.withPort(builder.build());
    }
    public N endPort(){
            return and();
    }

}


}
